#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-DUocg0wwlOn21a5G1A6AFu
key:                  haskell-language-server-2.3.0.0-DUocg0wwlOn21a5G1A6AFu
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f49eaf0179f3157edc9b1c43542b014c
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-DUocg0wwlOn21a5G1A6AFu
depends:
    aeson-pretty-0.8.10-FzHF9GoXKHa6sey9IGLZM9
    async-2.2.6-4Cg1cnm4CwuITQT2ZpqpLR base-4.18.2.1
    base16-bytestring-1.0.2.0-Kn1heJ4eFku33azk8Re0oa
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-Hxu26Sh76lDE7uR4nMDrN0
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-JQPIVWTyEPVHbx2JMbVQL9 filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-Eoa6tp1s2cQ3SPxlBsPi9A
    githash-0.1.7.0-IBSJ17TWtUjGsQEjaTN9mQ
    hie-bios-0.12.0-1ZG7JxVpAwmKZ3L4vzAhbb
    hiedb-0.4.3.0-LVwl48jIYql5wPtjHJS9ZX
    hls-alternate-number-format-plugin-2.3.0.0-Dl9oXidUgX85lmRJDza6Pb
    hls-cabal-fmt-plugin-2.3.0.0-AQCNf4AM7gYG5ayBYMAQIn
    hls-cabal-plugin-2.3.0.0-9d4UrsNYEta9fZg0x9uJmj
    hls-call-hierarchy-plugin-2.3.0.0-7C0Zb24erlSEBEeIX6B36g
    hls-change-type-signature-plugin-2.3.0.0-GiGUC5gwrYgFNWfaAwkGwI
    hls-class-plugin-2.3.0.0-Grcm99Cg4Rp1xIOC5MJpE9
    hls-code-range-plugin-2.3.0.0-EUqUVDSntbc4YvBDoPUAL5
    hls-eval-plugin-2.3.0.0-Ce1FK7thCzBExoKwAN6HuN
    hls-explicit-fixity-plugin-2.3.0.0-2LZI3CMoVXJIoP77BY154x
    hls-explicit-imports-plugin-2.3.0.0-LJCa39d1osK7Qvtv6WKtBO
    hls-explicit-record-fields-plugin-2.3.0.0-AXsK36lXKH07MeGhrfB85y
    hls-fourmolu-plugin-2.3.0.0-LJafPSpSG0f3jVWmQxHpF
    hls-gadt-plugin-2.3.0.0-GX9BhBy5t1dBt2KBBK1Nr9
    hls-graph-2.3.0.0-9HTV86GFbt7DwubseqDsg4
    hls-hlint-plugin-2.3.0.0-Esz7dw53Oo6IWOSXISrJQh
    hls-module-name-plugin-2.3.0.0-E5hNdp6fZdh3mcz6hMaose
    hls-ormolu-plugin-2.3.0.0-5uUIzVvekCx5Hj7S8OKulx
    hls-overloaded-record-dot-plugin-2.3.0.0-HGRBW08OsWwJm7UnK6i59l
    hls-plugin-api-2.3.0.0-7TrHSX8AWar6cYTbqf1BaR
    hls-pragmas-plugin-2.3.0.0-1E209fTtkqALmcExdPmXQS
    hls-qualify-imported-names-plugin-2.3.0.0-35NaM85wHND3kfxQKX0mxQ
    hls-refactor-plugin-2.3.0.0-4v8ZWpsb7zgJld9mVXT35b
    hls-rename-plugin-2.3.0.0-811HK5anL4d9ApZLoZkk1Q
    hls-retrie-plugin-2.3.0.0-7bxgWm8wgnQKatAg8SOgGM
    hls-splice-plugin-2.3.0.0-AOOHy82PyaE9N0toOmgXDf
    hls-stylish-haskell-plugin-2.3.0.0-B7D27wgRfjuWbCWBarddU
    lsp-2.2.0.0-KwTs0YLLLhs7xPAe9XbIIA
    optparse-applicative-0.18.1.0-BxGWYUUmFSvAWQPaHpJkSX
    optparse-simple-0.1.1.4-L6mhUlQ9W3p3UrtGy83BHm
    prettyprinter-1.7.1-H2rJD2WExIbcRy2n74kLf process-1.6.19.0
    safe-exceptions-0.1.7.4-H7PY7cHPlBiCkugjevNzTr
    sqlite-simple-0.4.19.0-2u8PvCK1AcGJyxvlrdpBL1 text-2.0.2
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

